@@ -31,7 +31,7 @@ class ClinicalQualityMeasure134v6Test(SDKBaseTest):
         self.assertEqual(expected, ClinicalQualityMeasure134v6._meta.description)
 
     def test_information(self):
-        expected = 'https://ecqi.healthit.gov/ecqm/measures/cms134v6'
+        expected = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS134v6.html'
         self.assertEqual(expected, ClinicalQualityMeasure134v6._meta.information)
 
     def test_version(self):
