@@ -15,6 +15,7 @@ import requests
 from canvas_workflow_kit import settings
 from canvas_workflow_kit.api import fetch_patient
 from canvas_workflow_kit.patient import Patient
+from canvas_workflow_kit.protocol import CONTEXT_REPORT
 from canvas_workflow_kit.timeframe import Timeframe
 from canvas_workflow_kit.internal.string import snakecase
 from canvas_workflow_kit.utils import (
@@ -161,11 +162,13 @@ def _process_fixture_from_patient(ctx, patient_key, output_directory):
 @click.option('--date')
 @click.option('--start-date')
 @click.option('--end-date')
+@click.option('--report-mode', default=False, is_flag=True, help="Run the class in report mode.")
 @click.option('--full', flag_value='full', default=False,
               help="Show the full output returned to the application.")
 def test_fixture(
     module_path: str, fixture_folder: str,
     date: str = None, start_date: str = None, end_date: str = None,
+    report_mode: bool = False,
     full: bool = False
 ):
     """
@@ -188,15 +191,16 @@ def test_fixture(
         for i, fixture_folder in enumerate(subdirectories):
             if i >= 1:
                 click.echo('-' * 80)
-            test_fixture_directory(fixture_folder, Class, date, start_date, end_date, full)
+            test_fixture_directory(fixture_folder, Class, date, start_date, end_date, report_mode, full)
 
     else:
-        test_fixture_directory(path, Class, date, start_date, end_date, full)
+        test_fixture_directory(path, Class, date, start_date, end_date, report_mode, full)
 
 
 def test_fixture_directory(
     fixture_folder: Path, Class: type,
     date: str = None, start_date: str = None, end_date: str = None,
+    report_mode: bool = False,
     full: bool = False
 ):
     # 2. load JSON folder of fixture data
@@ -225,6 +229,9 @@ def test_fixture_directory(
 
     # 3. instantiate module
     protocol = Class(patient=patient, date=date, timeframe=timeframe)
+    if report_mode:
+        protocol.context == CONTEXT_REPORT
+
     results = protocol.compute_results()
 
     # 4. return results
