@@ -1,5 +1,8 @@
 from enum import Enum
 
+COMMAND_TYPE_ALLERGY = 'allergy'
+COMMAND_TYPE_DIAGNOSE = 'diagnose'
+COMMAND_TYPE_FOLLOWUP = 'followUp'
 COMMAND_TYPE_IMAGING = 'imagingOrder'
 COMMAND_TYPE_IMMUNIZATION = 'immunization'
 COMMAND_TYPE_INSTRUCTION = 'instruct'
@@ -77,6 +80,9 @@ class CHANGE_TYPE:
     PATIENT = 'patient'
     "Recompute protocol when a patient's demographic information has been updated."
 
+    PRESCRIPTION = 'prescription'
+    "Recompute protocol when a patient's prescription information has been updated"
+
     PROTOCOL_OVERRIDE = 'protocol_override'
     "Recompute protocol when a protocol is overridden."
 
