@@ -6,6 +6,7 @@ from typing import Any, Dict, List, Optional, Type
 import arrow
 
 from canvas_workflow_kit.patient_recordset import (
+    AdministrativeDocumentRecordSet,
     AllergyIntoleranceRecordSet,
     PatientRecordSet,
     BillingLineItemRecordSet,
@@ -19,6 +20,7 @@ from canvas_workflow_kit.patient_recordset import (
     MedicationRecordSet,
     MessageRecordSet,
     ProtocolOverrideRecordSet,
+    PrescriptionRecordSet,
     ReasonForVisitRecordSet,
     ReferralRecordSet,
     ReferralReportRecordSet,
@@ -43,6 +45,7 @@ class Patient:
     SEX_MALE = 'M'
 
     RECORDSET_CLASSES = (
+        AdministrativeDocumentRecordSet,
         AllergyIntoleranceRecordSet,
         BillingLineItemRecordSet,
         ConditionRecordSet,
@@ -54,6 +57,7 @@ class Patient:
         LabReportRecordSet,
         MedicationRecordSet,
         ProtocolOverrideRecordSet,
+        PrescriptionRecordSet,
         ReasonForVisitRecordSet,
         ReferralRecordSet,
         ReferralReportRecordSet,
@@ -66,6 +70,10 @@ class Patient:
         self.patient = data.get('patient', None)
         self.active_only = False
 
+        self.administrative_documents = AdministrativeDocumentRecordSet.new_from(
+            data.get(AdministrativeDocumentRecordSet.API_UPDATE_FIELD, [])
+        )
+
         self.allergy_intolerances = AllergyIntoleranceRecordSet.new_from(
             data.get(AllergyIntoleranceRecordSet.API_UPDATE_FIELD, []))
 
@@ -99,6 +107,9 @@ class Patient:
         self.protocol_overrides = ProtocolOverrideRecordSet.new_from(
             data.get(ProtocolOverrideRecordSet.API_UPDATE_FIELD, []))
 
+        self.prescriptions = PrescriptionRecordSet.new_from(
+            data.get(PrescriptionRecordSet.API_UPDATE_FIELD, []))
+
         self.reason_for_visits = ReasonForVisitRecordSet.new_from(
             data.get(ReasonForVisitRecordSet.API_UPDATE_FIELD, []))
 
