@@ -28,6 +28,7 @@ URL_ICD10 = 'ICD-10'
 URL_NUCC = 'http://www.nucc.org/'
 URL_CANVAS = 'CANVAS'
 URL_INTERNAL = 'INTERNAL'
+URL_NDC = 'http://hl7.org/fhir/sid/ndc'
 
 CODE_SYSTEM_MAPPING = {
     'cpt': URL_CPT,
@@ -42,6 +43,7 @@ CODE_SYSTEM_MAPPING = {
     'nucc': URL_NUCC,
     'canvas': URL_CANVAS,
     'internal': URL_INTERNAL,
+    'ndc': URL_NDC
 }
 
 SYSTEM_CODE_MAPPING = {
@@ -55,6 +57,7 @@ SYSTEM_CODE_MAPPING = {
     URL_NUCC: ['nucc'],
     URL_CANVAS: ['canvas'],
     URL_INTERNAL: ['internal'],
+    URL_NDC: ['ndc']
 }
 
 
@@ -653,6 +656,19 @@ class ImagingReportRecordSet(PatientEventRecordSet):
             })
         return codes
 
+class PrescriptionRecordSet(PatientRecordSet):
+    VALID_SYSTEMS = [
+        'rxnorm',
+        'fdb',
+        'ndc'
+    ]
+    PATIENT_FIELD = 'prescriptions'
+    API_UPDATE_FIELD = 'prescriptions'
+
+    @staticmethod
+    def item_to_codes(item) -> List:
+        return item['coding']
+
 
 class ProtocolOverrideRecordSet(PatientRecordSet):
     VALID_SYSTEMS: List[str] = ['snomedct']
@@ -731,3 +747,9 @@ class AllergyIntoleranceRecordSet(PatientEventRecordSet):
     PATIENT_FIELD = 'allergy_intolerances'
     API_UPDATE_FIELD = 'allergyIntolerances'
     DATE_FIELD = 'onsetDate'
+
+class AdministrativeDocumentRecordSet(PatientEventRecordSet):
+    VALID_SYSTEMS: List[str] = ['canvas', 'internal']
+    PATIENT_FIELD = 'administrative_documents'
+    API_UPDATE_FIELD = 'administrativeDocuments'
+    DATE_FIELD = 'originalDate'
