@@ -32,6 +32,7 @@ class TestPatient(SDKBaseTest):
             'lab_reports',
             'medications',
             'protocol_overrides',
+            'prescriptions',
             'referral_reports',
             'vital_signs',
             'suspect_hccs',
@@ -54,6 +55,7 @@ class TestPatient(SDKBaseTest):
             'lab_reports': 1,
             'medications': 1,
             'protocol_overrides': 0,
+            'prescriptions': 0,
             'referral_reports': 0,
             'vital_signs': 2,
             'suspect_hccs': 0,
@@ -79,6 +81,7 @@ class TestPatient(SDKBaseTest):
             'lab_reports': 2,
             'medications': 2,
             'protocol_overrides': 2,
+            'prescriptions': 1,
             'referral_reports': 1,
             'vital_signs': 3,
             'suspect_hccs': 0,
@@ -92,6 +95,7 @@ class TestPatient(SDKBaseTest):
     def test_recordset_classes(self):
         tested = self.load_patient('full')
         expected = [
+            'AdministrativeDocumentRecordSet',
             'AllergyIntoleranceRecordSet',
             'BillingLineItemRecordSet',
             'ConditionRecordSet',
@@ -103,6 +107,7 @@ class TestPatient(SDKBaseTest):
             'LabReportRecordSet',
             'MedicationRecordSet',
             'ProtocolOverrideRecordSet',
+            'PrescriptionRecordSet',
             'ReasonForVisitRecordSet',
             'ReferralRecordSet',
             'ReferralReportRecordSet',
@@ -120,6 +125,7 @@ class TestPatient(SDKBaseTest):
     def test_recordset_fields(self):
         tested = self.load_patient('full')
         expected = [
+            'administrative_documents',
             'allergy_intolerances',
             'billing_line_items',
             'conditions',
@@ -131,6 +137,7 @@ class TestPatient(SDKBaseTest):
             'lab_reports',
             'medications',
             'protocol_overrides',
+            'prescriptions',
             'reason_for_visits',
             'referrals',
             'referral_reports',
@@ -320,6 +327,7 @@ class TestPatient(SDKBaseTest):
 
     def test_as_dict(self):
         fields = [
+            'administrative_documents',
             'allergy_intolerances',
             'billing_line_items',
             'conditions',
@@ -330,6 +338,7 @@ class TestPatient(SDKBaseTest):
             'lab_reports',
             'medications',
             'protocol_overrides',
+            'prescriptions',
             'reason_for_visits',
             'referrals',
             'referral_reports',
