@@ -15,6 +15,7 @@ from canvas_workflow_kit.patient_recordset import (
     PatientPeriodRecordSet,
     PatientRecordSet,
     ProtocolOverrideRecordSet,
+    PrescriptionRecordSet,
     ReferralReportRecordSet,
     VitalSignRecordSet
 )
@@ -1369,6 +1370,63 @@ class TestMedicationRecordSet(TestCase):
         ]
         self.assertEqual(expected, MedicationRecordSet.item_to_codes(item))
 
+class TestPrescriptionRecordSet(TestCase):
+
+    def test_constants(self):
+        tested = PrescriptionRecordSet([])
+        self.assertIsInstance(tested, PatientRecordSet)
+        self.assertEqual(['rxnorm', 'fdb', 'ndc'], tested.VALID_SYSTEMS)
+        self.assertEqual('prescriptions', tested.PATIENT_FIELD)
+        self.assertEqual('prescriptions', tested.API_UPDATE_FIELD)
+
+    def test_item_to_codes(self):
+        item = {
+            'codinx': [{
+                'system': '',
+                'code': 'cde113',
+                'display': 'The A'
+            }],
+            'coding': [
+                {
+                    'system': '',
+                    'code': 'cde123',
+                    'display': 'The A'
+                },
+                {
+                    'system': '',
+                    'code': 'cde124',
+                    'display': 'The B'
+                },
+                {
+                    'system': '',
+                    'code': 'cde125',
+                    'display': 'The C'
+                },
+            ],
+            'codiny': [{
+                'system': '',
+                'code': 'cde133',
+                'display': 'The A'
+            }],
+        }
+        expected = [
+            {
+                'system': '',
+                'code': 'cde123',
+                'display': 'The A'
+            },
+            {
+                'system': '',
+                'code': 'cde124',
+                'display': 'The B'
+            },
+            {
+                'system': '',
+                'code': 'cde125',
+                'display': 'The C'
+            },
+        ]
+        self.assertEqual(expected, PrescriptionRecordSet.item_to_codes(item))
 
 class TestInterviewRecordSet(TestCase):
 
